/*******************************************************************************
* File Name: OFFN.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "OFFN.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 OFFN__PORT == 15 && ((OFFN__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: OFFN_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void OFFN_Write(uint8 value) 
{
    uint8 staticBits = (OFFN_DR & (uint8)(~OFFN_MASK));
    OFFN_DR = staticBits | ((uint8)(value << OFFN_SHIFT) & OFFN_MASK);
}


/*******************************************************************************
* Function Name: OFFN_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  OFFN_DM_STRONG     Strong Drive 
*  OFFN_DM_OD_HI      Open Drain, Drives High 
*  OFFN_DM_OD_LO      Open Drain, Drives Low 
*  OFFN_DM_RES_UP     Resistive Pull Up 
*  OFFN_DM_RES_DWN    Resistive Pull Down 
*  OFFN_DM_RES_UPDWN  Resistive Pull Up/Down 
*  OFFN_DM_DIG_HIZ    High Impedance Digital 
*  OFFN_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void OFFN_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(OFFN_0, mode);
}


/*******************************************************************************
* Function Name: OFFN_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro OFFN_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 OFFN_Read(void) 
{
    return (OFFN_PS & OFFN_MASK) >> OFFN_SHIFT;
}


/*******************************************************************************
* Function Name: OFFN_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 OFFN_ReadDataReg(void) 
{
    return (OFFN_DR & OFFN_MASK) >> OFFN_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(OFFN_INTSTAT) 

    /*******************************************************************************
    * Function Name: OFFN_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 OFFN_ClearInterrupt(void) 
    {
        return (OFFN_INTSTAT & OFFN_MASK) >> OFFN_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
