/*******************************************************************************
* File Name: OFFP.h  
* Version 2.10
*
* Description:
*  This file containts Control Register function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_OFFP_H) /* Pins OFFP_H */
#define CY_PINS_OFFP_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "OFFP_aliases.h"

/* Check to see if required defines such as CY_PSOC5A are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5A)
    #error Component cy_pins_v2_10 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5A) */

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 OFFP__PORT == 15 && ((OFFP__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

void    OFFP_Write(uint8 value) ;
void    OFFP_SetDriveMode(uint8 mode) ;
uint8   OFFP_ReadDataReg(void) ;
uint8   OFFP_Read(void) ;
uint8   OFFP_ClearInterrupt(void) ;


/***************************************
*           API Constants        
***************************************/

/* Drive Modes */
#define OFFP_DM_ALG_HIZ         PIN_DM_ALG_HIZ
#define OFFP_DM_DIG_HIZ         PIN_DM_DIG_HIZ
#define OFFP_DM_RES_UP          PIN_DM_RES_UP
#define OFFP_DM_RES_DWN         PIN_DM_RES_DWN
#define OFFP_DM_OD_LO           PIN_DM_OD_LO
#define OFFP_DM_OD_HI           PIN_DM_OD_HI
#define OFFP_DM_STRONG          PIN_DM_STRONG
#define OFFP_DM_RES_UPDWN       PIN_DM_RES_UPDWN

/* Digital Port Constants */
#define OFFP_MASK               OFFP__MASK
#define OFFP_SHIFT              OFFP__SHIFT
#define OFFP_WIDTH              1u


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define OFFP_PS                     (* (reg8 *) OFFP__PS)
/* Data Register */
#define OFFP_DR                     (* (reg8 *) OFFP__DR)
/* Port Number */
#define OFFP_PRT_NUM                (* (reg8 *) OFFP__PRT) 
/* Connect to Analog Globals */                                                  
#define OFFP_AG                     (* (reg8 *) OFFP__AG)                       
/* Analog MUX bux enable */
#define OFFP_AMUX                   (* (reg8 *) OFFP__AMUX) 
/* Bidirectional Enable */                                                        
#define OFFP_BIE                    (* (reg8 *) OFFP__BIE)
/* Bit-mask for Aliased Register Access */
#define OFFP_BIT_MASK               (* (reg8 *) OFFP__BIT_MASK)
/* Bypass Enable */
#define OFFP_BYP                    (* (reg8 *) OFFP__BYP)
/* Port wide control signals */                                                   
#define OFFP_CTL                    (* (reg8 *) OFFP__CTL)
/* Drive Modes */
#define OFFP_DM0                    (* (reg8 *) OFFP__DM0) 
#define OFFP_DM1                    (* (reg8 *) OFFP__DM1)
#define OFFP_DM2                    (* (reg8 *) OFFP__DM2) 
/* Input Buffer Disable Override */
#define OFFP_INP_DIS                (* (reg8 *) OFFP__INP_DIS)
/* LCD Common or Segment Drive */
#define OFFP_LCD_COM_SEG            (* (reg8 *) OFFP__LCD_COM_SEG)
/* Enable Segment LCD */
#define OFFP_LCD_EN                 (* (reg8 *) OFFP__LCD_EN)
/* Slew Rate Control */
#define OFFP_SLW                    (* (reg8 *) OFFP__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define OFFP_PRTDSI__CAPS_SEL       (* (reg8 *) OFFP__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define OFFP_PRTDSI__DBL_SYNC_IN    (* (reg8 *) OFFP__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define OFFP_PRTDSI__OE_SEL0        (* (reg8 *) OFFP__PRTDSI__OE_SEL0) 
#define OFFP_PRTDSI__OE_SEL1        (* (reg8 *) OFFP__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define OFFP_PRTDSI__OUT_SEL0       (* (reg8 *) OFFP__PRTDSI__OUT_SEL0) 
#define OFFP_PRTDSI__OUT_SEL1       (* (reg8 *) OFFP__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define OFFP_PRTDSI__SYNC_OUT       (* (reg8 *) OFFP__PRTDSI__SYNC_OUT) 


#if defined(OFFP__INTSTAT)  /* Interrupt Registers */

    #define OFFP_INTSTAT                (* (reg8 *) OFFP__INTSTAT)
    #define OFFP_SNAP                   (* (reg8 *) OFFP__SNAP)

#endif /* Interrupt Registers */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_OFFP_H */


/* [] END OF FILE */
