/*******************************************************************************
* File Name: VDAC_OFFPN_PM.c  
* Version 1.90
*
* Description:
*  This file provides the power management source code to API for the
*  VDAC8.  
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "VDAC_OFFPN.h"

static VDAC_OFFPN_backupStruct VDAC_OFFPN_backup;


/*******************************************************************************
* Function Name: VDAC_OFFPN_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void VDAC_OFFPN_SaveConfig(void) 
{
    if (!((VDAC_OFFPN_CR1 & VDAC_OFFPN_SRC_MASK) == VDAC_OFFPN_SRC_UDB))
    {
        VDAC_OFFPN_backup.data_value = VDAC_OFFPN_Data;
    }
}


/*******************************************************************************
* Function Name: VDAC_OFFPN_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
*******************************************************************************/
void VDAC_OFFPN_RestoreConfig(void) 
{
    if (!((VDAC_OFFPN_CR1 & VDAC_OFFPN_SRC_MASK) == VDAC_OFFPN_SRC_UDB))
    {
        if((VDAC_OFFPN_Strobe & VDAC_OFFPN_STRB_MASK) == VDAC_OFFPN_STRB_EN)
        {
            VDAC_OFFPN_Strobe &= (uint8)(~VDAC_OFFPN_STRB_MASK);
            VDAC_OFFPN_Data = VDAC_OFFPN_backup.data_value;
            VDAC_OFFPN_Strobe |= VDAC_OFFPN_STRB_EN;
        }
        else
        {
            VDAC_OFFPN_Data = VDAC_OFFPN_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: VDAC_OFFPN_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  VDAC_OFFPN_backup.enableState:  Is modified depending on the enable 
*  state  of the block before entering sleep mode.
*
*******************************************************************************/
void VDAC_OFFPN_Sleep(void) 
{
    /* Save VDAC8's enable state */    
    if(VDAC_OFFPN_ACT_PWR_EN == (VDAC_OFFPN_PWRMGR & VDAC_OFFPN_ACT_PWR_EN))
    {
        /* VDAC8 is enabled */
        VDAC_OFFPN_backup.enableState = 1u;
    }
    else
    {
        /* VDAC8 is disabled */
        VDAC_OFFPN_backup.enableState = 0u;
    }
    
    VDAC_OFFPN_Stop();
    VDAC_OFFPN_SaveConfig();
}


/*******************************************************************************
* Function Name: VDAC_OFFPN_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  VDAC_OFFPN_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void VDAC_OFFPN_Wakeup(void) 
{
    VDAC_OFFPN_RestoreConfig();
    
    if(VDAC_OFFPN_backup.enableState == 1u)
    {
        /* Enable VDAC8's operation */
        VDAC_OFFPN_Enable();

        /* Restore the data register */
        VDAC_OFFPN_SetValue(VDAC_OFFPN_Data);
    } /* Do nothing if VDAC8 was disabled before */    
}


/* [] END OF FILE */
