/*******************************************************************************
* File Name: VDAC_VREF_PM.c  
* Version 1.90
*
* Description:
*  This file provides the power management source code to API for the
*  VDAC8.  
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "VDAC_VREF.h"

static VDAC_VREF_backupStruct VDAC_VREF_backup;


/*******************************************************************************
* Function Name: VDAC_VREF_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void VDAC_VREF_SaveConfig(void) 
{
    if (!((VDAC_VREF_CR1 & VDAC_VREF_SRC_MASK) == VDAC_VREF_SRC_UDB))
    {
        VDAC_VREF_backup.data_value = VDAC_VREF_Data;
    }
}


/*******************************************************************************
* Function Name: VDAC_VREF_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
*******************************************************************************/
void VDAC_VREF_RestoreConfig(void) 
{
    if (!((VDAC_VREF_CR1 & VDAC_VREF_SRC_MASK) == VDAC_VREF_SRC_UDB))
    {
        if((VDAC_VREF_Strobe & VDAC_VREF_STRB_MASK) == VDAC_VREF_STRB_EN)
        {
            VDAC_VREF_Strobe &= (uint8)(~VDAC_VREF_STRB_MASK);
            VDAC_VREF_Data = VDAC_VREF_backup.data_value;
            VDAC_VREF_Strobe |= VDAC_VREF_STRB_EN;
        }
        else
        {
            VDAC_VREF_Data = VDAC_VREF_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: VDAC_VREF_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  VDAC_VREF_backup.enableState:  Is modified depending on the enable 
*  state  of the block before entering sleep mode.
*
*******************************************************************************/
void VDAC_VREF_Sleep(void) 
{
    /* Save VDAC8's enable state */    
    if(VDAC_VREF_ACT_PWR_EN == (VDAC_VREF_PWRMGR & VDAC_VREF_ACT_PWR_EN))
    {
        /* VDAC8 is enabled */
        VDAC_VREF_backup.enableState = 1u;
    }
    else
    {
        /* VDAC8 is disabled */
        VDAC_VREF_backup.enableState = 0u;
    }
    
    VDAC_VREF_Stop();
    VDAC_VREF_SaveConfig();
}


/*******************************************************************************
* Function Name: VDAC_VREF_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  VDAC_VREF_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void VDAC_VREF_Wakeup(void) 
{
    VDAC_VREF_RestoreConfig();
    
    if(VDAC_VREF_backup.enableState == 1u)
    {
        /* Enable VDAC8's operation */
        VDAC_VREF_Enable();

        /* Restore the data register */
        VDAC_VREF_SetValue(VDAC_VREF_Data);
    } /* Do nothing if VDAC8 was disabled before */    
}


/* [] END OF FILE */
