/*******************************************************************************
* File Name: result.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "result.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 result__PORT == 15 && ((result__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: result_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void result_Write(uint8 value) 
{
    uint8 staticBits = (result_DR & (uint8)(~result_MASK));
    result_DR = staticBits | ((uint8)(value << result_SHIFT) & result_MASK);
}


/*******************************************************************************
* Function Name: result_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  result_DM_STRONG     Strong Drive 
*  result_DM_OD_HI      Open Drain, Drives High 
*  result_DM_OD_LO      Open Drain, Drives Low 
*  result_DM_RES_UP     Resistive Pull Up 
*  result_DM_RES_DWN    Resistive Pull Down 
*  result_DM_RES_UPDWN  Resistive Pull Up/Down 
*  result_DM_DIG_HIZ    High Impedance Digital 
*  result_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void result_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(result_0, mode);
	CyPins_SetPinDriveMode(result_1, mode);
	CyPins_SetPinDriveMode(result_2, mode);
	CyPins_SetPinDriveMode(result_3, mode);
	CyPins_SetPinDriveMode(result_4, mode);
	CyPins_SetPinDriveMode(result_5, mode);
	CyPins_SetPinDriveMode(result_6, mode);
	CyPins_SetPinDriveMode(result_7, mode);
}


/*******************************************************************************
* Function Name: result_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro result_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 result_Read(void) 
{
    return (result_PS & result_MASK) >> result_SHIFT;
}


/*******************************************************************************
* Function Name: result_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 result_ReadDataReg(void) 
{
    return (result_DR & result_MASK) >> result_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(result_INTSTAT) 

    /*******************************************************************************
    * Function Name: result_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 result_ClearInterrupt(void) 
    {
        return (result_INTSTAT & result_MASK) >> result_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
