/*******************************************************************************
* File Name: resultADDR.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "resultADDR.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 resultADDR__PORT == 15 && ((resultADDR__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: resultADDR_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void resultADDR_Write(uint8 value) 
{
    uint8 staticBits = (resultADDR_DR & (uint8)(~resultADDR_MASK));
    resultADDR_DR = staticBits | ((uint8)(value << resultADDR_SHIFT) & resultADDR_MASK);
}


/*******************************************************************************
* Function Name: resultADDR_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  resultADDR_DM_STRONG     Strong Drive 
*  resultADDR_DM_OD_HI      Open Drain, Drives High 
*  resultADDR_DM_OD_LO      Open Drain, Drives Low 
*  resultADDR_DM_RES_UP     Resistive Pull Up 
*  resultADDR_DM_RES_DWN    Resistive Pull Down 
*  resultADDR_DM_RES_UPDWN  Resistive Pull Up/Down 
*  resultADDR_DM_DIG_HIZ    High Impedance Digital 
*  resultADDR_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void resultADDR_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(resultADDR_0, mode);
	CyPins_SetPinDriveMode(resultADDR_1, mode);
	CyPins_SetPinDriveMode(resultADDR_2, mode);
	CyPins_SetPinDriveMode(resultADDR_3, mode);
}


/*******************************************************************************
* Function Name: resultADDR_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro resultADDR_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 resultADDR_Read(void) 
{
    return (resultADDR_PS & resultADDR_MASK) >> resultADDR_SHIFT;
}


/*******************************************************************************
* Function Name: resultADDR_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 resultADDR_ReadDataReg(void) 
{
    return (resultADDR_DR & resultADDR_MASK) >> resultADDR_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(resultADDR_INTSTAT) 

    /*******************************************************************************
    * Function Name: resultADDR_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 resultADDR_ClearInterrupt(void) 
    {
        return (resultADDR_INTSTAT & resultADDR_MASK) >> resultADDR_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
