/*******************************************************************************
* File Name: selH.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "selH.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 selH__PORT == 15 && ((selH__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: selH_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void selH_Write(uint8 value) 
{
    uint8 staticBits = (selH_DR & (uint8)(~selH_MASK));
    selH_DR = staticBits | ((uint8)(value << selH_SHIFT) & selH_MASK);
}


/*******************************************************************************
* Function Name: selH_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  selH_DM_STRONG     Strong Drive 
*  selH_DM_OD_HI      Open Drain, Drives High 
*  selH_DM_OD_LO      Open Drain, Drives Low 
*  selH_DM_RES_UP     Resistive Pull Up 
*  selH_DM_RES_DWN    Resistive Pull Down 
*  selH_DM_RES_UPDWN  Resistive Pull Up/Down 
*  selH_DM_DIG_HIZ    High Impedance Digital 
*  selH_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void selH_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(selH_0, mode);
	CyPins_SetPinDriveMode(selH_1, mode);
	CyPins_SetPinDriveMode(selH_2, mode);
	CyPins_SetPinDriveMode(selH_3, mode);
	CyPins_SetPinDriveMode(selH_4, mode);
	CyPins_SetPinDriveMode(selH_5, mode);
	CyPins_SetPinDriveMode(selH_6, mode);
	CyPins_SetPinDriveMode(selH_7, mode);
}


/*******************************************************************************
* Function Name: selH_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro selH_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 selH_Read(void) 
{
    return (selH_PS & selH_MASK) >> selH_SHIFT;
}


/*******************************************************************************
* Function Name: selH_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 selH_ReadDataReg(void) 
{
    return (selH_DR & selH_MASK) >> selH_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(selH_INTSTAT) 

    /*******************************************************************************
    * Function Name: selH_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 selH_ClearInterrupt(void) 
    {
        return (selH_INTSTAT & selH_MASK) >> selH_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
