/*******************************************************************************
* File Name: selL.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "selL.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 selL__PORT == 15 && ((selL__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: selL_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void selL_Write(uint8 value) 
{
    uint8 staticBits = (selL_DR & (uint8)(~selL_MASK));
    selL_DR = staticBits | ((uint8)(value << selL_SHIFT) & selL_MASK);
}


/*******************************************************************************
* Function Name: selL_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  selL_DM_STRONG     Strong Drive 
*  selL_DM_OD_HI      Open Drain, Drives High 
*  selL_DM_OD_LO      Open Drain, Drives Low 
*  selL_DM_RES_UP     Resistive Pull Up 
*  selL_DM_RES_DWN    Resistive Pull Down 
*  selL_DM_RES_UPDWN  Resistive Pull Up/Down 
*  selL_DM_DIG_HIZ    High Impedance Digital 
*  selL_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void selL_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(selL_0, mode);
	CyPins_SetPinDriveMode(selL_1, mode);
	CyPins_SetPinDriveMode(selL_2, mode);
	CyPins_SetPinDriveMode(selL_3, mode);
	CyPins_SetPinDriveMode(selL_4, mode);
	CyPins_SetPinDriveMode(selL_5, mode);
	CyPins_SetPinDriveMode(selL_6, mode);
	CyPins_SetPinDriveMode(selL_7, mode);
}


/*******************************************************************************
* Function Name: selL_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro selL_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 selL_Read(void) 
{
    return (selL_PS & selL_MASK) >> selL_SHIFT;
}


/*******************************************************************************
* Function Name: selL_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 selL_ReadDataReg(void) 
{
    return (selL_DR & selL_MASK) >> selL_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(selL_INTSTAT) 

    /*******************************************************************************
    * Function Name: selL_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 selL_ClearInterrupt(void) 
    {
        return (selL_INTSTAT & selL_MASK) >> selL_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
