/*******************************************************************************
* File Name: VDAC_OFFCTRL_PM.c  
* Version 1.90
*
* Description:
*  This file provides the power management source code to API for the
*  VDAC8.  
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "VDAC_OFFCTRL.h"

static VDAC_OFFCTRL_backupStruct VDAC_OFFCTRL_backup;


/*******************************************************************************
* Function Name: VDAC_OFFCTRL_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void VDAC_OFFCTRL_SaveConfig(void) 
{
    if (!((VDAC_OFFCTRL_CR1 & VDAC_OFFCTRL_SRC_MASK) == VDAC_OFFCTRL_SRC_UDB))
    {
        VDAC_OFFCTRL_backup.data_value = VDAC_OFFCTRL_Data;
    }
}


/*******************************************************************************
* Function Name: VDAC_OFFCTRL_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
*******************************************************************************/
void VDAC_OFFCTRL_RestoreConfig(void) 
{
    if (!((VDAC_OFFCTRL_CR1 & VDAC_OFFCTRL_SRC_MASK) == VDAC_OFFCTRL_SRC_UDB))
    {
        if((VDAC_OFFCTRL_Strobe & VDAC_OFFCTRL_STRB_MASK) == VDAC_OFFCTRL_STRB_EN)
        {
            VDAC_OFFCTRL_Strobe &= (uint8)(~VDAC_OFFCTRL_STRB_MASK);
            VDAC_OFFCTRL_Data = VDAC_OFFCTRL_backup.data_value;
            VDAC_OFFCTRL_Strobe |= VDAC_OFFCTRL_STRB_EN;
        }
        else
        {
            VDAC_OFFCTRL_Data = VDAC_OFFCTRL_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: VDAC_OFFCTRL_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  VDAC_OFFCTRL_backup.enableState:  Is modified depending on the enable 
*  state  of the block before entering sleep mode.
*
*******************************************************************************/
void VDAC_OFFCTRL_Sleep(void) 
{
    /* Save VDAC8's enable state */    
    if(VDAC_OFFCTRL_ACT_PWR_EN == (VDAC_OFFCTRL_PWRMGR & VDAC_OFFCTRL_ACT_PWR_EN))
    {
        /* VDAC8 is enabled */
        VDAC_OFFCTRL_backup.enableState = 1u;
    }
    else
    {
        /* VDAC8 is disabled */
        VDAC_OFFCTRL_backup.enableState = 0u;
    }
    
    VDAC_OFFCTRL_Stop();
    VDAC_OFFCTRL_SaveConfig();
}


/*******************************************************************************
* Function Name: VDAC_OFFCTRL_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  VDAC_OFFCTRL_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void VDAC_OFFCTRL_Wakeup(void) 
{
    VDAC_OFFCTRL_RestoreConfig();
    
    if(VDAC_OFFCTRL_backup.enableState == 1u)
    {
        /* Enable VDAC8's operation */
        VDAC_OFFCTRL_Enable();

        /* Restore the data register */
        VDAC_OFFCTRL_SetValue(VDAC_OFFCTRL_Data);
    } /* Do nothing if VDAC8 was disabled before */    
}


/* [] END OF FILE */
